@@ -24,14 +24,15 @@ import pytorch_lightning as pl
 from pytorch_lightning.callbacks.callback import Callback
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from pytorch_lightning.utilities.imports import _PSUTIL_AVAILABLE
-from pytorch_lightning.utilities.rank_zero import rank_zero_deprecation, rank_zero_warn
+from pytorch_lightning.utilities.rank_zero import rank_zero_warn
 from pytorch_lightning.utilities.types import STEP_OUTPUT
 
 
 class DeviceStatsMonitor(Callback):
     r"""
-    Automatically monitors and logs device stats during training stage. ``DeviceStatsMonitor``
-    is a special callback as it requires a ``logger`` to passed as argument to the ``Trainer``.
+    Automatically monitors and logs device stats during training, validation and testing stage.
+    ``DeviceStatsMonitor`` is a special callback as it requires a ``logger`` to passed as argument
+    to the ``Trainer``.
 
     Args:
         cpu_stats: if ``None``, it will log CPU stats only if the accelerator is CPU.
@@ -58,7 +59,7 @@ class DeviceStatsMonitor(Callback):
         self,
         trainer: "pl.Trainer",
         pl_module: "pl.LightningModule",
-        stage: Optional[str] = None,
+        stage: str,
     ) -> None:
         if stage != "fit":
             return
@@ -109,15 +110,38 @@ class DeviceStatsMonitor(Callback):
     ) -> None:
         self._get_and_log_device_stats(trainer, "on_train_batch_end")
 
+    def on_validation_batch_start(
+        self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", batch: Any, batch_idx: int, dataloader_idx: int
+    ) -> None:
+        self._get_and_log_device_stats(trainer, "on_validation_batch_start")
+
+    def on_validation_batch_end(
+        self,
+        trainer: "pl.Trainer",
+        pl_module: "pl.LightningModule",
+        outputs: Optional[STEP_OUTPUT],
+        batch: Any,
+        batch_idx: int,
+        dataloader_idx: int,
+    ) -> None:
+        self._get_and_log_device_stats(trainer, "on_validation_batch_end")
+
+    def on_test_batch_start(
+        self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", batch: Any, batch_idx: int, dataloader_idx: int
+    ) -> None:
+        self._get_and_log_device_stats(trainer, "on_test_batch_start")
+
+    def on_test_batch_end(
+        self,
+        trainer: "pl.Trainer",
+        pl_module: "pl.LightningModule",
+        outputs: Optional[STEP_OUTPUT],
+        batch: Any,
+        batch_idx: int,
+        dataloader_idx: int,
+    ) -> None:
+        self._get_and_log_device_stats(trainer, "on_test_batch_end")
+
 
 def _prefix_metric_keys(metrics_dict: Dict[str, float], prefix: str, separator: str) -> Dict[str, float]:
     return {prefix + separator + k: v for k, v in metrics_dict.items()}
-
-
-def prefix_metric_keys(metrics_dict: Dict[str, float], prefix: str) -> Dict[str, float]:
-    rank_zero_deprecation(
-        "`pytorch_lightning.callbacks.device_stats_monitor.prefix_metrics`"
-        " is deprecated in v1.6 and will be removed in v1.8."
-    )
-    sep = ""
-    return _prefix_metric_keys(metrics_dict, prefix, sep)
