@@ -13,7 +13,7 @@
 # limitations under the License.
 from typing import Any, Dict, Optional
 
-from lightning_lite.plugins import CheckpointIO
+from lightning_fabric.plugins import CheckpointIO
 
 
 class _WrappingCheckpointIO(CheckpointIO):
