@@ -15,23 +15,17 @@
 
 import numpy
 
-from lightning_lite.utilities import move_data_to_device  # noqa: F401
-from lightning_lite.utilities import AMPType, LightningEnum  # noqa: F401
+from lightning_fabric.utilities import LightningEnum  # noqa: F401
+from lightning_fabric.utilities import move_data_to_device  # noqa: F401
 from pytorch_lightning.utilities.distributed import AllGatherGrad  # noqa: F401
 from pytorch_lightning.utilities.enums import GradClipAlgorithmType  # noqa: F401
 from pytorch_lightning.utilities.grads import grad_norm  # noqa: F401
 from pytorch_lightning.utilities.imports import (  # noqa: F401
-    _APEX_AVAILABLE,
     _HIVEMIND_AVAILABLE,
-    _HOROVOD_AVAILABLE,
     _HPU_AVAILABLE,
     _IPU_AVAILABLE,
-    _IS_WINDOWS,
     _OMEGACONF_AVAILABLE,
     _POPTORCH_AVAILABLE,
-    _TORCH_GREATER_EQUAL_1_10,
-    _TORCH_GREATER_EQUAL_1_11,
-    _TORCH_GREATER_EQUAL_1_12,
     _TORCH_QUANTIZE_AVAILABLE,
     _TORCHVISION_AVAILABLE,
 )
